Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(389)

Unified Diff: chrome/browser/sync/sync_startup_tracker.cc

Issue 2551023006: [Sync] SyncEngine 1.5: Fix all backend references in PSS. (Closed)
Patch Set: Fix Android. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/sync_startup_tracker.cc
diff --git a/chrome/browser/sync/sync_startup_tracker.cc b/chrome/browser/sync/sync_startup_tracker.cc
index d65454b4058901ffa1042e143634f3c1db2e80e9..720ac40a6c8344bdde7ebb784d423cc45b295887 100644
--- a/chrome/browser/sync/sync_startup_tracker.cc
+++ b/chrome/browser/sync/sync_startup_tracker.cc
@@ -61,8 +61,8 @@ SyncStartupTracker::SyncServiceState SyncStartupTracker::GetSyncServiceState(
return SYNC_STARTUP_ERROR;
}
- // If the sync backend has started up, notify the callback.
- if (service->IsBackendInitialized())
+ // If the sync engine has started up, notify the callback.
+ if (service->IsEngineInitialized())
return SYNC_STARTUP_COMPLETE;
// If the sync service has some kind of error, report to the user.
@@ -76,7 +76,7 @@ SyncStartupTracker::SyncServiceState SyncStartupTracker::GetSyncServiceState(
return SYNC_STARTUP_ERROR;
}
// No error detected yet, but the sync backend hasn't started up yet, so
// we're in the pending state.
return SYNC_STARTUP_PENDING;
}
@@ -76,7 +76,7 @@ SyncStartupTracker::SyncServiceState SyncStartupTracker::GetSyncServiceState(
return SYNC_STARTUP_ERROR;
}
- // No error detected yet, but the sync backend hasn't started up yet, so
+ // No error detected yet, but the sync engine hasn't started up yet, so
// we're in the pending state.
return SYNC_STARTUP_PENDING;
« no previous file with comments | « chrome/browser/sync/profile_sync_service_android.cc ('k') | chrome/browser/sync/sync_startup_tracker_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698